@@ -14,7 +14,7 @@ use Fcntl qw(:flock);
 
 use Exporter qw(import);
 
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 our @EXPORT_OK = qw(start_server restart_server stop_server server_ports);
 
 my @signals_received;
@@ -389,7 +389,9 @@ sub start_server {
             my $kill_old_delay = defined $ENV{KILL_OLD_DELAY} ? $ENV{KILL_OLD_DELAY} : $ENV{ENABLE_AUTO_RESTART} ? 5 : 0;
             if ($kill_old_delay != 0) {
                 print STDERR "sleeping $kill_old_delay secs before killing old workers\n";
-                sleep $kill_old_delay;
+                while ($kill_old_delay > 0) {
+                    $kill_old_delay -= sleep $kill_old_delay || 1;
+                }
             }
             print STDERR "killing old workers\n";
             kill $opts->{signal_on_hup}, $_
@@ -563,7 +565,7 @@ Server::Starter - a superdaemon for hot-deploying server programs
 
 =head1 DESCRIPTION
 
-It is often a pain to write a server program that supports graceful restarts, with no resource leaks.  L<Server::Starter> solves the problem by splitting the task into two.  One is L<start_server>, a script provided as a part of the module, which works as a superdaemon that binds to zero or more TCP ports or unix sockets, and repeatedly spawns the server program that actually handles the necessary tasks (for example, responding to incoming commenctions).  The spawned server programs under L<Server::Starter> call accept(2) and handle the requests.
+It is often a pain to write a server program that supports graceful restarts, with no resource leaks.  L<Server::Starter> solves the problem by splitting the task into two.  One is L<start_server>, a script provided as a part of the module, which works as a superdaemon that binds to zero or more TCP ports or unix sockets, and repeatedly spawns the server program that actually handles the necessary tasks (for example, responding to incoming connections).  The spawned server programs under L<Server::Starter> call accept(2) and handle the requests.
 
 To gracefully restart the server program, send SIGHUP to the superdaemon.  The superdaemon spawns a new server program, and if (and only if) it starts up successfully, sends SIGTERM to the old server program.
 
